Чтобы не отправлять в Last.fm джинглы, другие служебные файлы или просто только
что загруженную музыку, которая ещё не прошла проверку, можно составить
специальный чёрный список меток.

Пример фрагмента конфигурационного файла (ardj.yaml):

    lastfm_skip_labels: [tagme, jingle, podcast]
